@@ -20,7 +20,7 @@
 #include "GenericDatum.hh"
 #include "ValidSchema.hh"
 
-#include <boost/test/included/unit_test_framework.hpp>
+#include <boost/test/included/unit_test.hpp>
 #include <boost/test/parameterized_test.hpp>
 #include <boost/test/unit_test.hpp>
 
